Update language to comply with Android's inclusive language guidance

See https://source.android.com/setup/contribute/respectful-code for reference

#inclusivefixit

Bug=161896447
Test: ./gradlew bOS

Change-Id: I0c4e047dfcfa4678fec14971fc5a83e1ecc4a10d
diff --git a/room/compiler/build.gradle b/room/compiler/build.gradle
index 263b88f..6aed8258 100644
--- a/room/compiler/build.gradle
+++ b/room/compiler/build.gradle
@@ -215,7 +215,7 @@
         result.write("fail\n")
         validatePublishTaskOutputs()
         validatePomTaskOutputs()
-        // have a dummy output to make gradle happy w/ input/output checking.
+        // have a no-op output to make gradle happy w/ input/output checking.
         result.write("ok\n")
     }
 }
diff --git a/room/compiler/src/main/kotlin/androidx/room/parser/SqlParser.kt b/room/compiler/src/main/kotlin/androidx/room/parser/SqlParser.kt
index c542239..82dc4e6 100644
--- a/room/compiler/src/main/kotlin/androidx/room/parser/SqlParser.kt
+++ b/room/compiler/src/main/kotlin/androidx/room/parser/SqlParser.kt
@@ -155,7 +155,7 @@
             input.isNotBlank() && INVALID_IDENTIFIER_CHARS.none { input.contains(it) }
 
         /**
-         * creates a dummy select query for raw queries that queries the given list of tables.
+         * creates a no-op select query for raw queries that queries the given list of tables.
          */
         fun rawQueryForTables(tableNames: Set<String>): ParsedQuery {
             return ParsedQuery(
diff --git a/room/compiler/src/main/kotlin/androidx/room/processor/EntityOrViewProcessor.kt b/room/compiler/src/main/kotlin/androidx/room/processor/EntityOrViewProcessor.kt
index 189281b..20e9590 100644
--- a/room/compiler/src/main/kotlin/androidx/room/processor/EntityOrViewProcessor.kt
+++ b/room/compiler/src/main/kotlin/androidx/room/processor/EntityOrViewProcessor.kt
@@ -31,7 +31,7 @@
 }
 
 /**
- * A dummy implementation of [EntityOrViewProcessor] that just prints a processor error for use of
+ * A no-op implementation of [EntityOrViewProcessor] that just prints a processor error for use of
  * an invalid class as [EntityOrView].
  */
 private class NonEntityOrViewProcessor(
diff --git a/room/compiler/src/main/kotlin/androidx/room/verifier/DatabaseVerifier.kt b/room/compiler/src/main/kotlin/androidx/room/verifier/DatabaseVerifier.kt
index 41d80e8..a57927b 100644
--- a/room/compiler/src/main/kotlin/androidx/room/verifier/DatabaseVerifier.kt
+++ b/room/compiler/src/main/kotlin/androidx/room/verifier/DatabaseVerifier.kt
@@ -69,7 +69,7 @@
             // UUID named library files.
             synchronized(System::class.java) {
                 SQLiteJDBCLoader.initialize() // extract and loads native library
-                JDBC.isValidURL(CONNECTION_URL) // dummy call to register driver
+                JDBC.isValidURL(CONNECTION_URL) // call to register driver
             }
         }
 
diff --git a/room/compiler/src/test/kotlin/androidx/room/testing/test_util.kt b/room/compiler/src/test/kotlin/androidx/room/testing/test_util.kt
index dbd6418..96333e8 100644
--- a/room/compiler/src/test/kotlin/androidx/room/testing/test_util.kt
+++ b/room/compiler/src/test/kotlin/androidx/room/testing/test_util.kt
@@ -198,7 +198,7 @@
     f: (TestInvocation) -> Unit
 ): CompileTester {
     return Truth.assertAbout(JavaSourcesSubjectFactory.javaSources())
-            .that(jfos.toList() + JavaFileObjects.forSourceLines("Dummy", "final class Dummy {}"))
+            .that(jfos.toList() + JavaFileObjects.forSourceLines("NoOp", "final class NoOp {}"))
             .apply {
                 if (classpathFiles.isNotEmpty()) {
                     withClasspath(classpathFiles)
diff --git a/room/compiler/src/test/kotlin/androidx/room/verifier/DatabaseVerifierTest.kt b/room/compiler/src/test/kotlin/androidx/room/verifier/DatabaseVerifierTest.kt
index f9dedc4..8ae3d2e 100644
--- a/room/compiler/src/test/kotlin/androidx/room/verifier/DatabaseVerifierTest.kt
+++ b/room/compiler/src/test/kotlin/androidx/room/verifier/DatabaseVerifierTest.kt
@@ -291,7 +291,7 @@
         tableName: String,
         vararg fields: Field
     ): Entity {
-        val element = invocation.processingEnv.requireTypeElement("Dummy")
+        val element = invocation.processingEnv.requireTypeElement("NoOp")
         return Entity(
             element = element,
             tableName = tableName,
diff --git a/room/integration-tests/kotlintestapp/src/androidTest/java/androidx/room/integration/kotlintestapp/migration/MigrationDbKotlin.kt b/room/integration-tests/kotlintestapp/src/androidTest/java/androidx/room/integration/kotlintestapp/migration/MigrationDbKotlin.kt
index 1517a4a..3d7219b 100644
--- a/room/integration-tests/kotlintestapp/src/androidTest/java/androidx/room/integration/kotlintestapp/migration/MigrationDbKotlin.kt
+++ b/room/integration-tests/kotlintestapp/src/androidTest/java/androidx/room/integration/kotlintestapp/migration/MigrationDbKotlin.kt
@@ -18,16 +18,16 @@
 
 import android.content.ContentValues
 import android.database.sqlite.SQLiteDatabase
-import androidx.room.Entity
-import androidx.room.Database
-import androidx.room.RoomDatabase
-import androidx.room.Index
-import androidx.room.PrimaryKey
-import androidx.room.ForeignKey
-import androidx.room.Query
-import androidx.room.Insert
-import androidx.room.Ignore
 import androidx.room.Dao
+import androidx.room.Database
+import androidx.room.Entity
+import androidx.room.ForeignKey
+import androidx.room.Ignore
+import androidx.room.Index
+import androidx.room.Insert
+import androidx.room.PrimaryKey
+import androidx.room.Query
+import androidx.room.RoomDatabase
 import androidx.room.RoomWarnings
 import androidx.sqlite.db.SupportSQLiteDatabase
 
@@ -105,7 +105,7 @@
             val insertionId = mDb.insert(Entity1.TABLE_NAME,
                     SQLiteDatabase.CONFLICT_REPLACE, values)
             if (insertionId == -1L) {
-                throw RuntimeException("test sanity failure")
+                throw RuntimeException("test failure")
             }
         }
     }
@@ -122,7 +122,7 @@
             val insertionId = mDb.insert(Entity2.TABLE_NAME,
                     SQLiteDatabase.CONFLICT_REPLACE, values)
             if (insertionId == -1L) {
-                throw RuntimeException("test sanity failure")
+                throw RuntimeException("test failure")
             }
         }
     }
diff --git a/room/integration-tests/testapp/src/androidTest/java/androidx/room/integration/testapp/migration/MigrationDb.java b/room/integration-tests/testapp/src/androidTest/java/androidx/room/integration/testapp/migration/MigrationDb.java
index 24c2c89..45ed433 100644
--- a/room/integration-tests/testapp/src/androidTest/java/androidx/room/integration/testapp/migration/MigrationDb.java
+++ b/room/integration-tests/testapp/src/androidTest/java/androidx/room/integration/testapp/migration/MigrationDb.java
@@ -133,7 +133,7 @@
             long insertionId = mDb.insert(Entity1.TABLE_NAME,
                     SQLiteDatabase.CONFLICT_REPLACE, values);
             if (insertionId == -1) {
-                throw new RuntimeException("test sanity failure");
+                throw new RuntimeException("test failure");
             }
         }
     }
@@ -155,7 +155,7 @@
             long insertionId = mDb.insert(Entity2.TABLE_NAME,
                     SQLiteDatabase.CONFLICT_REPLACE, values);
             if (insertionId == -1) {
-                throw new RuntimeException("test sanity failure");
+                throw new RuntimeException("test failure");
             }
         }
     }
diff --git a/room/runtime/src/main/java/androidx/room/util/CopyLock.java b/room/runtime/src/main/java/androidx/room/util/CopyLock.java
index 3750315f..8db020c 100644
--- a/room/runtime/src/main/java/androidx/room/util/CopyLock.java
+++ b/room/runtime/src/main/java/androidx/room/util/CopyLock.java
@@ -43,7 +43,7 @@
  *     Thread locking within the same JVM process is done via a map of String key to ReentrantLock
  *     objects.
  *   <li>
- *     Multi-process locking is done via a dummy file whose name contains the key and FileLock
+ *     Multi-process locking is done via a lock file whose name contains the key and FileLock
  *     objects.
  *
  * @hide
diff --git a/room/integration-tests/testapp/src/androidTest/java/androidx/room/integration/testapp/migration/MigrationTest.java b/room/integration-tests/testapp/src/androidTest/java/androidx/room/integration/testapp/migration/MigrationTest.java
index 95a47e8..a9d78c8 100644
--- a/room/integration-tests/testapp/src/androidTest/java/androidx/room/integration/testapp/migration/MigrationTest.java
+++ b/room/integration-tests/testapp/src/androidTest/java/androidx/room/integration/testapp/migration/MigrationTest.java
@@ -496,10 +496,10 @@
                 .fallbackToDestructiveMigrationOnDowngrade()
                 .addMigrations(MIGRATION_MAX_LATEST)
                 .build();
-        // Check that two dummy values are present, confirming the database migration was successful
-        long dummyRowsCount = db.getOpenHelper().getReadableDatabase().compileStatement(
-                "SELECT count(*) FROM Dummy").simpleQueryForLong();
-        assertThat(dummyRowsCount, is(2L));
+        // Check that two values are present, confirming the database migration was successful
+        long rowsCount = db.getOpenHelper().getReadableDatabase().compileStatement(
+                "SELECT count(*) FROM NoOp").simpleQueryForLong();
+        assertThat(rowsCount, is(2L));
         db.close();
     }
 
@@ -662,7 +662,7 @@
      * {@link MigrationDb#LATEST_VERSION} that uses the schema file and re-creates the tables such
      * that the post-migration validation passes.
      *
      * Additionally, it adds a table named Dummy with two rows to be able to distinguish this
      * migration from a destructive migration.
      *
      * This migration allows us to keep creating new schemas for newer tests without updating the
@@ -688,10 +688,10 @@
                 throw new RuntimeException(e);
             }
 
-            database.execSQL("CREATE TABLE IF NOT EXISTS `Dummy` (`id` INTEGER NOT NULL,"
+            database.execSQL("CREATE TABLE IF NOT EXISTS `NoOp` (`id` INTEGER NOT NULL,"
                     + " PRIMARY KEY(`id`))");
-            database.execSQL("INSERT INTO `Dummy` (`id`) VALUES (1)");
-            database.execSQL("INSERT INTO `Dummy` (`id`) VALUES (2)");
+            database.execSQL("INSERT INTO `NoOp` (`id`) VALUES (1)");
+            database.execSQL("INSERT INTO `NoOp` (`id`) VALUES (2)");
         }
     };
 
@@ -662,7 +662,7 @@
      * that the post-migration validation passes.
      *
-     * Additionally, it adds a table named Dummy with two rows to be able to distinguish this
+     * Additionally, it adds a table named NoOp with two rows to be able to distinguish this
      * migration from a destructive migration.
      *